@@ -77,10 +77,10 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "      Shutdown when run finished\n"
         "      Default: 60\n"
         "\n"
-        "    server [<address> [<port> [<password>]]]:\n"
-        "      Boot web service\n"
-        '      Default: server "" 0\n'
-        "      Client send command 'kill' can exit ripper's run, note that FFmpeg needs to accept multiple ^C signals to forcibly terminate, and a single ^C signal will wait for the file output to be complete before terminating\n"
+        "  server [<address> [<port> [<password>]]]:\n"
+        "    Boot web service\n"
+        '    Default: server "" 0\n'
+        "    Client send command 'kill' can exit ripper's run, note that FFmpeg needs to accept multiple ^C signals to forcibly terminate, and a single ^C signal will wait for the file output to be complete before terminating\n"
         "\n"
         "    config <config option>:\n"
         "      regenerate | clear | clean | reset\n"
@@ -92,8 +92,12 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "      set <key> <val>\n"
         "        Set config, e.g. config set language zh\n"
         "\n"
+        "  translate <files' infix> <target lang tag> [-overwrite]\n"
+        "    Translate subtitle files\n"
+        "    e.g. 'translate zh-Hans zh-Hant' will translate all '.zh-Hans.ass' files into zh-Hant\n"
+        "\n"
         "  <Option>\n"
-        "    -i <input> -o <output> [-o:dir <dir>] -preset <preset name> [-pipe <vpy pathname> -crf <val> -psy-rd <val> ...] [-sub <subtitle pathname>] [-c:a <audio encoder> -b:a <audio bitrate>] [-muxer <muxer> [-r <fps>]] [-run [<run option>]]\n"
+        "    -i <input> -p <preset name> [-o <output>] [-o:dir <dir>] [-pipe <vpy pathname> -crf <val> -psy-rd <val> ...] [-sub <subtitle pathname>] [-c:a <audio encoder> -b:a <audio bitrate>] [-muxer <muxer> [-r <fps>]] [-run [<run option>]]\n"
         "      Add a new ripper to the ripper list, you can set the values of the options in preset individually, you can run ripper list when use -run\n"
         "\n"
         "\n"
@@ -109,7 +113,7 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         '      e.g. "name--?{start=6,padding=4,increment=2}--?{time:%Y.%m.%S}"\n'
         "\n"
         "  -auto-infix <0 | 1>\n"
-        "    If enable, output file name will have auto infix:\n"
+        "    If enable, output file name will add auto infix:\n"
         "      no audio: '.v'\n"
         "      with audio: '.va'\n"
         "    Default: 1\n"
@@ -185,6 +189,10 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "    Some error will interrupt subset\n"
         "    Default: 0\n"
         "\n"
+        "  -translate-sub <infix>:<language tag>\n"
+        "    Temporary generation of subtitle translation files\n"
+        "    e.g. 'zh-Hans:zh-Hant' will temporary generation of Traditional Chinese subtitles\n"
+        "\n"
         "  -c:a <string>\n"
         "    Setting audio encoder\n"
         "\n"
