@@ -77,10 +77,10 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "      执行后关机\n"
         "      默认: 60\n"
         "\n"
-        "    server [<地址> [<端口> [<密码>]]]:\n"
-        "      启动 web 服务\n"
-        '      默认: server "" 0\n'
-        "      客户端发送命令 'kill' 可以退出 ripper 的运行，注意，FFmpeg需要接受多次^C信号才能强制终止，单次^C会等待文件输出完才会终止\n"
+        "  server [<地址> [<端口> [<密码>]]]:\n"
+        "    启动 web 服务\n"
+        '    默认: server "" 0\n'
+        "    客户端发送命令 'kill' 可以退出 ripper 的运行，注意，FFmpeg需要接受多次^C信号才能强制终止，单次^C会等待文件输出完才会终止\n"
         "\n"
         "    config <config 选项>:\n"
         "      regenerate | clear | clean | reset\n"
@@ -92,8 +92,12 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "      set <key> <val>\n"
         "        设置 config，例如 config set language en\n"
         "\n"
+        "  translate <中缀> <目标语言标签> [-overwrite]\n"
+        "    翻译字幕文件\n"
+        "    例如 'translate zh-Hans zh-Hant' 将翻译所有 '.zh-Hans.ass' 文件为 zh-Hant\n"
+        "\n"
         "  <Option>\n"
-        "    -i <输入> -o <输出> [-o:dir <目录>] -preset <预设名> [-pipe <vpy 路径名> -crf <值> -psy-rd <值> ...] [-sub <字幕文件路径名>] [-c:a <音频编码器> -b:a <音频码率>] [-muxer <复用器> [-r <帧率>]] [-run [<run 选项>]]\n"
+        "    -i <输入> -p <预设名> [-o <输出>] [-o:dir <目录>] [-pipe <vpy 路径名> -crf <值> -psy-rd <值> ...] [-sub <字幕文件路径名>] [-c:a <音频编码器> -b:a <音频码率>] [-muxer <复用器> [-r <帧率>]] [-run [<run 选项>]]\n"
         "      往 ripper list 中添加一个 ripper，你可以单独设置预设中每个选项的值，使用 -run 执行 ripper\n"
         "\n"
         "\n"
@@ -109,10 +113,10 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         '      e.g. "name--?{start=6,padding=4,increment=2}--?{time:%Y.%m.%S}"\n'
         "\n"
         "  -auto-infix <0 | 1>\n"
-        "    If enable, output file name will have auto infix:\n"
-        "      no audio: '.v'\n"
-        "      with audio: '.va'\n"
-        "    Default: 1\n"
+        "    如果启用，输出的文件将添加自动中缀:\n"
+        "      无音轨: '.v'\n"
+        "      有音轨: '.va'\n"
+        "    默认: 1\n"
         "\n"
         "  -o:dir <string>\n"
         "    输出文件的目标目录\n"
@@ -149,7 +153,7 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "    'auto:...'可以只选择指定中缀，例如'auto:zh-Hans:zh-Hant'\n"
         "\n"
         "  -only-mux-sub-path <string>\n"
-        "    All subtitles and fonts in this path will be muxed\n"
+        "    该目录下所有的字幕和字体文件将加入混流\n"
         "\n"
         "  -soft-sub <string[?string...] | 'auto' | 'auto:...'>\n"
         "    往 MKV 中封装子集化字幕\n"
@@ -185,6 +189,10 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
         "    子集化时报错则中断\n"
         "    默认: 0\n"
         "\n"
+        "  -translate-sub <中缀>:<语言标签>\n"
+        "    临时生成字幕的翻译文件\n"
+        "    例如 'zh-Hans:zh-Hant' 将临时生成繁体字幕\n"
+        "\n"
         "  -c:a <string>\n"
         "    设置音频编码器\n"
         "\n"
@@ -282,6 +290,7 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     'The file "{}" does not exist': '文件 "{}" 不存在',
     "No subtitle file exist as -sub auto when -i {} -o:dir {}": "-sub auto 没有在 -i {} -o:dir {} 中找到对应字幕文件",
     "Unsupported option: {}": "不支持的选项: {}",
+    "Unsupported param: {}": "不支持的参数: {}",
     "Manually force exit": "手动强制退出",
     "or run '{}' when you use pip": "或运行 '{}' 以使用 pip 更新",
     "Wrong sec in -shutdown, change to default 60s": "-shutdown 设定的秒数错误，改为默认值 60s",
@@ -303,6 +312,9 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     "'{}' is not a valid '{}', set to default value '{}'. Valid options are: {}": "'{}' 不存在于 '{}'，已设为默认值 '{}'。有以下值可用: {}",
     "The preset custom must have custom:format or custom:template": "custom 预设必须要有 custom:format 或 custom:template",
     "There have error in running": "执行时出错",
+    "{} param illegal": "{} 参数非法",
+    'The file "{}" already exists, skip translating it': '文件 "{}" 已存在，跳过翻译',
+    "Subset faild, cancel mux": "子集化失败，取消混流",
     "FFmpeg report: {}": "FFmpeg 报告: {}",
     "{} not found. Skip it": "没找到 {}。默认跳过",
     'The font "{}" does not contain these characters: {}': '字体 "{}" 不包含字符: {}',
@@ -329,6 +341,9 @@ lang_map: dict[str | Global_lang_val.Extra_text_index, str] = {
     "Do not write to log file": "不写入日志文件",
     "Logs this level and above will be printed, and if the value is 'none', they will not be printed, support: {}": "此等级及以上的日志会打印到控制台，若值为 'none' 则不打印，支持: {}",
     "Logs this level and above will be written, and if the value is 'none', they will not be written, support: {}": "此等级及以上的日志会写入日志文件，若值为 'none' 则不写入，支持: {}",
+    # 第三方 API
+    "Translating into '{target_lang}' using '{api_name}'": "正在使用 '{api_name}' 翻译为 '{target_lang}'",
     # 通用
     "Run {} failed": "执行 {} 失败",
+    "Unknown error": "未知错误",
 }
