@@ -38,15 +38,15 @@ class Style_fmt_it(enum.Enum):
 #     Data = "Dialogue"
 
 
-@dataclass
+@dataclass(slots=True)
 class Script_info_data:
     # type: Script_info_type
     raw_str: str
 
 
-@dataclass
+@dataclass(slots=True)
 class Script_info:
-    data: list[Script_info_data] = field(default_factory=list)
+    data: list[Script_info_data] = field(default_factory=list[Script_info_data])
 
     def to_ass_str(self) -> str:
         return "\n".join(
@@ -57,7 +57,7 @@ class Script_info:
         )
 
 
-@dataclass
+@dataclass(slots=True)
 class Style_data:
     Name: str
     Fontname: str
@@ -111,7 +111,7 @@ DEFAULT_STYLE_FMT_ORDER = (
 )
 
 
-@dataclass
+@dataclass(slots=True)
 class Styles:
     fmt_order: tuple[
         Style_fmt_it,
@@ -165,7 +165,7 @@ class Styles:
             Style_fmt_it.Encoding: 22,
         }
     )
-    data: list[Style_data] = field(default_factory=list)
+    data: list[Style_data] = field(default_factory=list[Style_data])
 
     def flush_fmt_order_index(self):
         for it in self.fmt_order:
@@ -282,7 +282,7 @@ class Event_type(enum.Enum):
     Comment = "Comment"
 
 
-@dataclass
+@dataclass(slots=True)
 class Event_data:
     type: Event_type
 
@@ -302,7 +302,7 @@ class Event_data:
         if not use_libass_spec:
             # 模式1: 不处理转义字符
             result: list[tuple[bool, str]] = []
-            current = []  # 当前累积的字符
+            current = list[str]()  # 当前累积的字符
             in_tag = False  # 是否在标签内
 
             for char in text:
@@ -332,7 +332,7 @@ class Event_data:
         else:
             # 模式2: 处理转义字符（libass规范）
             result = []
-            current = []  # 当前累积的字符
+            current = list[str]()  # 当前累积的字符
             in_tag = False  # 是否在标签内
             escape_next = False  # 下一个字符是否转义
 
@@ -387,7 +387,7 @@ DEFAULT_EVENT_FMT_ORDER = (
 )
 
 
-@dataclass
+@dataclass(slots=True)
 class Events:
     fmt_order: tuple[
         Event_fmt_it,
@@ -415,7 +415,7 @@ class Events:
             Event_fmt_it.Text: 9,
         }
     )
-    data: list[Event_data] = field(default_factory=list)
+    data: list[Event_data] = field(default_factory=list[Event_data])
 
     def flush_fmt_order_index(self):
         for it in self.fmt_order:
@@ -442,7 +442,7 @@ class Events:
             str,
             str,
         ],
-        event_type,
+        event_type: Event_type,
     ) -> Event_data:
         try:
             res = Event_data(
@@ -504,7 +504,7 @@ class Attach_type(enum.Enum):
     Graphics = "Graphics"
 
 
-@dataclass
+@dataclass(slots=True)
 class Attachment_data:
     type: Attach_type
     name: str
@@ -537,9 +537,9 @@ class Attachment_data:
             self.org_data = new_data
 
 
-@dataclass
+@dataclass(slots=True)
 class Attachments:
-    data: list[Attachment_data] = field(default_factory=list)
+    data: list[Attachment_data] = field(default_factory=list[Attachment_data])
 
     def to_ass_str(
         self,
@@ -570,10 +570,10 @@ class Attachments:
         return res[1:] if len(res) else ""  # 去除头部的 \n
 
 
-@dataclass
-class Unknow_data:
+@dataclass(slots=True)
+class Unknown_data:
     head: str
-    data: list[str] = field(default_factory=list)
+    data: list[str] = field(default_factory=list[str])
 
     def to_ass_str(self) -> str:
         return "\n".join(
@@ -598,18 +598,18 @@ class Ass:
         self.styles: Styles = Styles()
         self.attachments: Attachments = Attachments()
         self.events: Events = Events()
-        self.unknow_data: list[Unknow_data] = []
+        self.unknown_data: list[Unknown_data] = []
 
         class State(enum.Enum):
-            unknow = enum.auto()
+            unknown = enum.auto()
             script_info = enum.auto()
             styles = enum.auto()
             fonts = enum.auto()
             graphics = enum.auto()
             events = enum.auto()
 
-        state: State = State.unknow
-        new_unknow_data: Unknow_data | None = None
+        state: State = State.unknown
+        new_unknown_data: Unknown_data | None = None
 
         for line in read_text(path).splitlines():
             line = line.strip()
@@ -618,9 +618,9 @@ class Ass:
                 continue
 
             if line.startswith("[") and line.endswith("]"):
-                if new_unknow_data is not None:
-                    self.unknow_data.append(new_unknow_data)
-                    new_unknow_data = None
+                if new_unknown_data is not None:
+                    self.unknown_data.append(new_unknown_data)
+                    new_unknown_data = None
 
                 match head := line[1:-1]:
                     case "Script Info":
@@ -635,8 +635,8 @@ class Ass:
                         state = State.events
                     case _:
                         if bool(re.search(r"[a-z]", head)):
-                            state = State.unknow
-                            new_unknow_data = Unknow_data(head)
+                            state = State.unknown
+                            new_unknown_data = Unknown_data(head)
 
             elif line.startswith("Format:"):
                 formats_generator = (v.strip() for v in line[7:].split(","))
@@ -685,7 +685,7 @@ class Ass:
                             )
                         else:
                             if self.attachments.data[-1].data is None:
-                                log.error("Unknow error", deep=True)
+                                log.error("Unknown error", deep=True)
                                 continue
                             self.attachments.data[-1].data += line + "\n"
 
@@ -700,7 +700,7 @@ class Ass:
                             )
                         else:
                             if self.attachments.data[-1].data is None:
-                                log.error("Unknow error", deep=True)
+                                log.error("Unknown error", deep=True)
                                 continue
                             self.attachments.data[-1].data += line + "\n"
 
@@ -730,18 +730,18 @@ class Ass:
                             self.events.new_data(event_tuple, event_type)
                         )
 
-                    case State.unknow:
-                        if new_unknow_data is None:
+                    case State.unknown:
+                        if new_unknown_data is None:
                             log.error(
                                 "Unknown error occurred when read line: {}",
                                 line,
                                 deep=True,
                             )
                             raise Ass_generation_failed()
-                        new_unknow_data.data.append(line)
+                        new_unknown_data.data.append(line)
 
-        if new_unknow_data is not None:
-            self.unknow_data.append(new_unknow_data)
+        if new_unknown_data is not None:
+            self.unknown_data.append(new_unknown_data)
 
     def __str__(
         self,
@@ -759,7 +759,7 @@ class Ass:
             self.events.to_ass_str(drop_non_render=drop_non_render),
             *(
                 data.to_ass_str()
-                for data in (() if drop_unkow_data else self.unknow_data)
+                for data in (() if drop_unkow_data else self.unknown_data)
             ),
         )
         return "\n\n".join(v for v in generator if v) + "\n"
