@@ -8,12 +8,12 @@ import enum
 import shutil
 from time import sleep
 from threading import Thread
-from typing import Iterable
+from typing import Callable, Iterable, Self
 
 from .. import easyrip_web
 from ..easyrip_log import log
-from ..easyrip_mlang import gettext, Global_lang_val
-from . import media_info
+from ..easyrip_mlang import gettext, Global_lang_val, translate_subtitles
+from .media_info import Media_info
 from .utils import get_base62_time
 from .font_subset import subset
 
@@ -116,7 +116,7 @@ class Ripper:
             )
             return default
 
-    @dataclass
+    @dataclass(slots=True)
     class Option:
         preset_name: "Ripper.PresetName"
         encoder_format_str: str
@@ -135,9 +135,9 @@ class Ripper:
 
     preset_name: PresetName
 
-    info: media_info.Media_info
+    info: Media_info
 
-    _progress: dict
+    _progress: dict[str, int | float]
     """
     .frame_count : int 总帧数
     .frame : int 已输出帧数
@@ -159,7 +159,7 @@ class Ripper:
     ):
         self.input_path_list = [Path(path) for path in input_path]
 
-        self.info = media_info.get_media_info(self.input_path_list[0])
+        self.info = Media_info.from_path(self.input_path_list[0])
 
         self.output_prefix_list = [
             path[0] or (path[1] or self.input_path_list[-1]).stem
@@ -186,7 +186,7 @@ class Ripper:
             self.preset_name = Ripper.PresetName.custom
             self.option = option
 
-        self._progress = {}
+        self._progress = dict[str, int | float]()
 
     def __str__(self):
         return (
@@ -256,7 +256,7 @@ class Ripper:
             )
             _bitrate_str = (
                 ""
-                if audio_encoder == Ripper.AudioCodec.copy
+                if audio_encoder in {Ripper.AudioCodec.copy, Ripper.AudioCodec.flac}
                 else f"-b:a {self.option_map.get('b:a') or '160k'}"
             )
             audio_option = f"{_encoder_str}{_bitrate_str} "
@@ -438,6 +438,8 @@ class Ripper:
                             if muxer == Ripper.Muxer.mp4
                             else 'mkvmerge -o "{output}" "{input}"'
                         )
+                    case _ as param:
+                        log.error("Unsupported param: {}", f"-c:a {param}")
 
             case Ripper.PresetName.flac:
                 _ff_encode_str: str = ""
@@ -653,7 +655,7 @@ class Ripper:
                     "weightb": "1",
                     "info": "1",
                 }
-                _custom_option_map = {
+                _custom_option_map: dict[str, str | None] = {
                     "crf": self.option_map.get("crf"),
                     "qpmin": self.option_map.get("qpmin"),
                     "qpmax": self.option_map.get("qpmax"),
@@ -843,7 +845,7 @@ class Ripper:
                         _option_map = {
                             "crf": "17",
                             "qpmin": "3",
-                            "qpmax": "20",
+                            "qpmax": "21.5",
                             "psy-rd": "2.2",
                             "rd": "5",
                             "rdoq-level": "2",
@@ -994,7 +996,10 @@ class Ripper:
         easyrip_web.http_server.Event.progress.append({})
         easyrip_web.http_server.Event.progress.popleft()
 
-    def run(self, prep_func=lambda _: None) -> bool:
+    def run(
+        self,
+        prep_func: Callable[[Self], None] = lambda _: None,
+    ) -> bool:
         if not self.input_path_list[0].exists():
             log.error('The file "{}" does not exist', self.input_path_list[0])
             return False
@@ -1241,16 +1246,20 @@ class Ripper:
                     [_flac_basename],
                     self.output_dir,
                     Ripper.PresetName.flac,
-                    (
-                        self.option_map
-                        | {
-                            "_sub_ripper_num": str(
-                                int(self.option_map.get("_sub_ripper_num", 0)) + 1
-                            ),
-                            "_sub_ripper_title": "FLAC Enc",
-                            "muxer": "mkv",
-                        }
-                    ),
+                    {
+                        k: v
+                        for k, v in (
+                            self.option_map
+                            | {
+                                "_sub_ripper_num": str(
+                                    int(self.option_map.get("_sub_ripper_num", 0)) + 1
+                                ),
+                                "_sub_ripper_title": "FLAC Enc",
+                                "muxer": "mkv",
+                            }
+                        ).items()
+                        if k not in {"soft-sub", "sub", "translate-sub"}
+                    },
                 )
                 _flac_ripper.run()
 
@@ -1275,17 +1284,20 @@ class Ripper:
                         Ripper.PresetName.copy,
                         {
                             k: v
-                            for k, v in {
-                                "_sub_ripper_num": str(
-                                    int(self.option_map.get("_sub_ripper_num", 0)) + 1
-                                ),
-                                "_sub_ripper_title": "FLAC Mux",
-                                "auto-infix": "0",
-                                "c:a": "copy",
-                                "muxer": _mux_muxer,
-                                "r": self.option_map.get("r"),
-                                "fps": self.option_map.get("fps"),
-                            }.items()
+                            for k, v in dict[str, str | None](
+                                {
+                                    "_sub_ripper_num": str(
+                                        int(self.option_map.get("_sub_ripper_num", 0))
+                                        + 1
+                                    ),
+                                    "_sub_ripper_title": "FLAC Mux",
+                                    "auto-infix": "0",
+                                    "c:a": "copy",
+                                    "muxer": _mux_muxer,
+                                    "r": self.option_map.get("r"),
+                                    "fps": self.option_map.get("fps"),
+                                }
+                            ).items()
                             if v
                         },
                     )
@@ -1298,7 +1310,7 @@ class Ripper:
             # 内封字幕合成
             if soft_sub := self.option_map.get("soft-sub"):
                 # 处理 soft-sub
-                soft_sub_list: list[str]
+                soft_sub_list: list[Path]
                 soft_sub_map_list: list[str] = soft_sub.split(":")
                 if soft_sub_map_list[0] == "auto":
                     soft_sub_list = []
@@ -1331,16 +1343,49 @@ class Ripper:
                             )
                         ):
                             soft_sub_list.append(
-                                os.path.join(self.output_dir, _file_basename)
+                                Path(os.path.join(self.output_dir, _file_basename))
                             )
                 else:
-                    soft_sub_list = soft_sub.split("?")
+                    soft_sub_list = [Path(s) for s in soft_sub.split("?")]
 
-                # 子集化
                 subset_folder = Path(self.output_dir) / f"subset_temp_{temp_name}"
                 log.info("-soft-sub list = {}", soft_sub_list)
+
+                # 临时翻译
+                add_tr_files = list[Path]()
+                if translate_sub := self.option_map.get("translate-sub"):
+                    _tr = translate_sub.split(":")
+                    if not len(_tr) == 2:
+                        log.error("{} param illegal", "-translate-sub")
+                    else:
+                        try:
+                            _file_list = translate_subtitles(
+                                Path(self.output_dir),
+                                _tr[0],
+                                _tr[1],
+                                file_intersection_selector=(
+                                    Path(s) for s in soft_sub_list
+                                ),
+                            )
+                        except Exception as e:
+                            log.error(e, is_format=False)
+                        else:
+                            for f_and_s in _file_list:
+                                if f_and_s[0].is_file():
+                                    log.warning(
+                                        'The file "{}" already exists, skip translating it',
+                                        f_and_s[0],
+                                    )
+                                    continue
+                                with f_and_s[0].open(
+                                    "wt", encoding="utf-8-sig", newline="\n"
+                                ) as f:
+                                    f.write(f_and_s[1])
+                                    add_tr_files.append(f_and_s[0])
+
+                # 子集化
                 if Ripper(
-                    soft_sub_list,
+                    soft_sub_list + add_tr_files,
                     (subset_folder.name,),
                     self.output_dir,
                     Ripper.PresetName.subset,
@@ -1360,18 +1405,21 @@ class Ripper:
                         Ripper.PresetName.copy,
                         {
                             k: v
-                            for k, v in {
-                                "only-mux-sub-path": str(subset_folder),
-                                "_sub_ripper_num": str(
-                                    int(self.option_map.get("_sub_ripper_num", 0)) + 1
-                                ),
-                                "_sub_ripper_title": "Soft Sub Mux",
-                                "auto-infix": "0",
-                                "c:a": self.option_map.get("c:a") and "copy",
-                                "muxer": "mkv",
-                                "r": self.option_map.get("r"),
-                                "fps": self.option_map.get("fps"),
-                            }.items()
+                            for k, v in dict[str, str | None](
+                                {
+                                    "only-mux-sub-path": str(subset_folder),
+                                    "_sub_ripper_num": str(
+                                        int(self.option_map.get("_sub_ripper_num", 0))
+                                        + 1
+                                    ),
+                                    "_sub_ripper_title": "Soft Sub Mux",
+                                    "auto-infix": "0",
+                                    "c:a": self.option_map.get("c:a") and "copy",
+                                    "muxer": "mkv",
+                                    "r": self.option_map.get("r"),
+                                    "fps": self.option_map.get("fps"),
+                                }
+                            ).items()
                             if v
                         },
                     ).run():
@@ -1380,7 +1428,13 @@ class Ripper:
                 else:
                     log.error("Subset faild, cancel mux")
 
+                # 清理临时文件
                 shutil.rmtree(subset_folder)
+                for f in add_tr_files:
+                    try:
+                        f.unlink()
+                    except Exception as e:
+                        log.error(f"{repr(e)} {e}", deep=True, is_format=False)
 
         # 获取 ffmpeg report 中的报错
         if FF_REPORT_LOG_FILE.is_file():
